@@ -306,6 +306,7 @@ class pltstyle(styleapplicator):
             'yaxis.title_font.tickfont.size',
             'legend.font.size'
         ]
-    def set_all_font_sizes(self, figure, font_size=common_defaults['Font_Size']):
-        for key in pltstyle.all_font_keys:
+    @staticmethod
+    def set_all_font_sizes(figure, font_size=common_defaults['Font_Size']):
+        for key in pltstyle.all_font_keys():
             update_fig(figure, **{key:font_size})
